@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.11 2003/04/09 18:47:50 hadess Exp $
+ * $Id: bacon-video-widget.h,v 1.18 2003/04/25 16:55:00 hadess Exp $
  *
  * the xine engine in a widget - header
  */
@@ -24,7 +24,7 @@
 #ifndef HAVE_BACON_VIDEO_WIDGET_H
 #define HAVE_BACON_VIDEO_WIDGET_H
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtkvbox.h>
 
 G_BEGIN_DECLS
 
@@ -39,6 +39,12 @@ typedef enum {
 	MEDIA_CDDA,
 } MediaType;
 
+typedef enum {
+	TV_OUT_NONE,
+	TV_OUT_DXR3,
+	TV_OUT_TVMODE,
+} TvOutType;
+
 typedef enum {
 	BVW_INFO_TITLE,
 	BVW_INFO_ARTIST,
@@ -64,12 +70,12 @@ typedef enum {
 typedef struct BaconVideoWidgetPrivate BaconVideoWidgetPrivate;
 
 typedef struct {
-	GtkWidget widget;
+	GtkVBox parent;
 	BaconVideoWidgetPrivate *priv;
 } BaconVideoWidget;
 
 typedef struct {
-	GtkWidgetClass parent_class;
+	GtkVBoxClass parent_class;
 
 	void (*error) (GtkWidget *bvw, const char *message);
 	void (*eos) (GtkWidget *bvw);
@@ -83,6 +89,8 @@ GtkWidget *bacon_video_widget_new		 (int width, int height,
 						  gboolean null_video_out,
 						  GError **error);
 
+char *bacon_video_widget_get_backend_name (BaconVideoWidget *bvw);
+
 /* Actions */
 gboolean bacon_video_widget_open		 (BaconVideoWidget *bvw,
 						  const gchar *mrl,
@@ -98,7 +106,8 @@ gboolean bacon_video_widget_play                 (BaconVideoWidget *bvw,
 void bacon_video_widget_stop                     (BaconVideoWidget *bvw);
 void bacon_video_widget_close                    (BaconVideoWidget *bvw);
 gboolean bacon_video_widget_eject                (BaconVideoWidget *bvw);
-
+void bacon_video_widget_set_logo                 (BaconVideoWidget *bvw,
+                                                  gchar *filename);
 /* Properties */
 void  bacon_video_widget_set_logo_mode		 (BaconVideoWidget *bvw,
 						  gboolean logo_mode);
@@ -108,6 +117,10 @@ void bacon_video_widget_set_speed                (BaconVideoWidget *bvw,
 		                                  Speeds speed);
 int bacon_video_widget_get_speed                 (BaconVideoWidget *bvw);
 
+void bacon_video_widget_set_proprietary_plugins_path
+						 (BaconVideoWidget *bvw,
+				                  const char *path);
+
 void bacon_video_widget_set_fullscreen           (BaconVideoWidget *bvw,
 						  gboolean fullscreen);
 gboolean bacon_video_widget_is_fullscreen        (BaconVideoWidget *bvw);
@@ -132,6 +145,14 @@ void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
 
+void bacon_video_widget_set_deinterlacing	 (BaconVideoWidget *bvw,
+						  gboolean deinterlace);
+gboolean bacon_video_widget_get_deinterlacing	 (BaconVideoWidget *bvw);
+
+gboolean bacon_video_widget_set_tv_out		 (BaconVideoWidget *bvw,
+						  TvOutType tvout);
+TvOutType bacon_video_widget_get_tv_out		 (BaconVideoWidget *bvw);
+
 void bacon_video_widget_toggle_aspect_ratio      (BaconVideoWidget *bvw);
 void bacon_video_widget_set_scale_ratio          (BaconVideoWidget *bvw,
 						  gfloat ratio);
